@@ -27,7 +27,7 @@ from kodexa.assistant import Assistant
 from kodexa.connectors import get_source
 from kodexa.connectors.connectors import get_caller_dir, FolderConnector
 from kodexa.model import Document, ExtensionPack
-from kodexa.model.objects import AssistantDefinition, Action, Taxonomy, ModelRuntime, Credential, Event, \
+from kodexa.model.objects import AssistantDefinition, Action, Taxonomy, ModelRuntime, Credential, ExecutionEvent, \
     ContentObject
 from kodexa.pipeline import PipelineContext, Pipeline, PipelineStatistics
 from kodexa.stores import RemoteDocumentStore, RemoteDataStore
@@ -525,12 +525,6 @@ class KodexaPlatform:
         else:
             logger.info(f"Deploying {metadata_object.type} {ref}")
 
-            access_token = KodexaPlatform.get_access_token_details()
-
-            if organization_slug not in access_token.organizationSlugs:
-                logger.warning(f"You do not have access to the organization {organization_slug}")
-                raise Exception("Unable to deploy, no access to organization")
-
             if object_version:
                 url = f"{KodexaPlatform.get_url()}/api/{object_url}/{organization_slug}/{object_slug}/{object_version}"
             else:
@@ -1130,8 +1124,16 @@ class ExtensionHelper:
 
 class EventHelper:
 
-    def __init__(self, event: Event):
-        self.event: Event = event
+    def __init__(self, event: ExecutionEvent):
+        self.event: ExecutionEvent = event
+
+    def log(self, message: str):
+        requests.post(
+            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution_id}/log",
+            [
+                {'entry': message}
+            ],
+            headers={'x-access-token': KodexaPlatform.get_access_token()}, timeout=300)
 
     def get_content_object(self, content_object_id: str):
         logger.info(
